Package: OmicsMLRepoR
Type: Package
Title: Search harmonized metadata created under the OmicsMLRepo project
Version: 1.6.0
Date: 2026-3-19
Authors@R: 
    c(person(given = "Sehyun",
             family = "Oh",
             role = c("aut", "cre"),
             email = "shbrief@gmail.com",
             comment = c(ORCID = "0000-0002-9490-3061")),
      person(given = "Kaelyn",
             family = "Long",
             email = "krlong586@gmail.com",
             role = "aut"))
Description: This package provides functions to browse the harmonized metadata for large omics databases. This package also supports data navigation if the metadata incorporates ontology. 
Depends: R (>= 4.4.0)
Imports: dplyr, stringr, rols, tidyr, methods, stats, tibble,
        data.tree, jsonlite, plyr, BiocFileCache, readr, DiagrammeR,
        rlang, lubridate
Suggests: arrow, knitr, BiocStyle, curatedMetagenomicData, testthat (>=
        3.0.0), cBioPortalData
License: Artistic-2.0
biocViews: Software, Infrastructure, DataRepresentation
Encoding: UTF-8
RoxygenNote: 7.3.3
VignetteBuilder: knitr
URL: https://github.com/shbrief/OmicsMLRepoR
BugReports: https://github.com/shbrief/OmicsMLRepoR/issues
git_url: https://git.bioconductor.org/packages/OmicsMLRepoR
git_branch: RELEASE_3_23
git_last_commit: 75e8efd
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-28 23:40:39 UTC; biocbuild
Author: Sehyun Oh [aut, cre] (ORCID: <https://orcid.org/0000-0002-9490-3061>),
  Kaelyn Long [aut]
Maintainer: Sehyun Oh <shbrief@gmail.com>
