#' OmicsMLRepoR: A package for browsing harmonized metadata through ontology
#'
#' The OmicsMLRepoR package provides functions to browse the harmonized 
#' metadata created under the OmicsMLRepo project. It supports data 
#' navigation if the metadata incorporates ontology. 
#'
#' @section Key Functions:
#' \itemize{
#'   \item \code{\link{getMetadata}}: Download a harmonized metadata table
#'   \item \code{\link{tree_filter}}: Find samples including the queried 
#'   terms and their descendants
#' }
#'
#' @section Additional Information:
#' For more detailed information, see the vignette:
#' \code{vignette("Quickstart", package = "OmicsMLRepoR")}
#'
#' @name OmicsMLRepoR
NULL
